@@ -50,6 +50,8 @@ class VaildityTester(object):
         :param proxy:
         :return:
         """
+        url = self.config.get("TSET_API")
+        out_time = self.config.get("TEST_TIME_OUT")
         try:
             async with aiohttp.ClientSession() as session:
                 if isinstance(proxy, bytes):
@@ -57,10 +59,10 @@ class VaildityTester(object):
                 real_proxy = proxy.replace("s", "")
                 try:
                     async with session.get(
-                            self.config.get("TSET_API"),
-                            headers=Headers().headers(),
+                            url,
+                            headers=Headers().headers(url),
                             proxy=real_proxy,
-                            timeout=self.config.get("TEST_TIME_OUT")
+                            timeout=out_time
                     ) as response:
                         if response.status == 200:
                             try:
